==> haskell-js-jquery-3.2.1-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-js-jquery.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: js-jquery
version: 3.2.1
id: js-jquery-3.2.1-Hsf3Jwb3LY22DKxRKtBs05
key: js-jquery-3.2.1-Hsf3Jwb3LY22DKxRKtBs05
license: MIT
copyright: Neil Mitchell 2014-2017
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/js-jquery#readme
synopsis: Obtain minified jQuery code
description:
    This package bundles the minified <http://jquery.com/ jQuery> code into a Haskell package,
    so it can be depended upon by Cabal packages. The first three components of
    the version number match the upstream jQuery version. The package is designed
    to meet the redistribution requirements of downstream users (e.g. Debian).
category: Javascript
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Language.Javascript.JQuery
hidden-modules: Paths_js_jquery
abi: 4cd88024197a48dfaa780ea5eb3b22a1
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/js-jquery-3.2.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/js-jquery-3.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-js-jquery
hs-libraries: HSjs-jquery-3.2.1-Hsf3Jwb3LY22DKxRKtBs05
depends:
    base-4.10.1.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-js-jquery/html/js-jquery.haddock
haddock-html: /usr/share/doc/haskell-js-jquery/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-js-jquery-3.3.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-js-jquery.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: js-jquery
version: 3.3.1
id: js-jquery-3.3.1-INvwHizaGP7LL6tydVCYG
key: js-jquery-3.3.1-INvwHizaGP7LL6tydVCYG
license: MIT
copyright: Neil Mitchell 2014-2018
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/js-jquery#readme
synopsis: Obtain minified jQuery code
description:
    This package bundles the minified <http://jquery.com/ jQuery> code into a Haskell package,
    so it can be depended upon by Cabal packages. The first three components of
    the version number match the upstream jQuery version. The package is designed
    to meet the redistribution requirements of downstream users (e.g. Debian).
category: Javascript
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Language.Javascript.JQuery
hidden-modules: Paths_js_jquery
abi: 09cbbfd1c19f878ea24ebd1084acd7ce
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/js-jquery-3.3.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/js-jquery-3.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-js-jquery
hs-libraries: HSjs-jquery-3.3.1-INvwHizaGP7LL6tydVCYG
depends:
    base-4.10.1.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-js-jquery/html/js-jquery.haddock
haddock-html: /usr/share/doc/haskell-js-jquery/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
